@@ -1,6 +1,5 @@
 package Dist::Zilla::PluginBundle::FAYLAND;
-$Dist::Zilla::PluginBundle::FAYLAND::VERSION = '0.14';
-
+$Dist::Zilla::PluginBundle::FAYLAND::VERSION = '0.15';
 # ABSTRACT: Dist::Zilla like FAYLAND when you build your dists
 
 use Moose;
@@ -10,33 +9,28 @@ with 'Dist::Zilla::Role::PluginBundle';
 use Dist::Zilla::PluginBundle::Filter;
 
 sub bundle_config {
-    my ( $self, $section ) = @_;
-    my $class = ( ref $self ) || $self;
+    my ($self, $section) = @_;
+    my $class = (ref $self) || $self;
 
     my $arg = $section->{payload};
 
-    my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config(
-        {
+    my @plugins = Dist::Zilla::PluginBundle::Filter->bundle_config({
             name    => "$class/Classic",
             payload => {
                 bundle => '@Classic',
                 remove => [qw(PodVersion BumpVersion Readme)],
-            }
-        }
-    );
+            }});
 
     my $prefix = 'Dist::Zilla::Plugin::';
-    my @extra =
-      map { [ "$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1] ] } (
-        [ PodWeaver           => {} ],
-        [ 'Test::Compile'     => {} ],
-        [ PerlTidy            => {} ],
-        [ Repository          => {} ],
-        [ ReadmeFromPod       => {} ],
-        [ CheckChangeLog      => {} ],
-        [ MetaJSON            => {} ],
-        [ 'Git::Contributors' => {} ]
-      );
+    my @extra = map { ["$class/$prefix$_->[0]" => "$prefix$_->[0]" => $_->[1]] } (
+        [PodWeaver           => {}],
+        ['Test::Compile'     => {}],
+        [PerlTidy            => {}],
+        [Repository          => {}],
+        [ReadmeFromPod       => {}],
+        [CheckChangeLog      => {}],
+        [MetaJSON            => {}],
+        ['Git::Contributors' => {}]);
 
     push @plugins, @extra;
 
@@ -62,7 +56,7 @@ Dist::Zilla::PluginBundle::FAYLAND - Dist::Zilla like FAYLAND when you build you
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -92,7 +86,7 @@ Fayland Lam <fayland@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Fayland Lam.
+This software is copyright (c) 2018 by Fayland Lam.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
